@@ -1,5 +1,7 @@
 # copied and modified from tensorflow::install.R, https://github.com/rstudio/tensorflow/blob/master/R/install.R
 
+conda_args <- reticulate:::conda_args
+
 #' Install spaCy in conda or virtualenv environment
 #'
 #' @description Install spaCy in a self-contained environment, including
@@ -25,14 +27,13 @@
 #'   automatically install the latest version of spaCy v1.*, using \code{version
 #'   = "latest_v1"}.
 #'   
-#' @inheritParams reticulate::conda_list
 #' @param conda character; path to conda executable. Default "auto" which
 #'   automatically find the path
 #' @param pip \code{TRUE} to use pip for installing spacy. If \code{FALSE}, conda 
 #' package manager with conda-forge channel will be used for installing spacy.
 #' @param lang_models character; language models to be installed. Default
-#'   \code{en} (English model). A vector of multiple model names can be used
-#'   (e.g. \code{c("en", "de")}).  A list of available language models and their
+#'   \code{en_core_web_sm} (English model). A vector of multiple model names can be used
+#'   (e.g. \code{c("en_core_web_sm", "de_core_news_sm")}).  A list of available language models and their
 #'   names is available from the \href{https://spacy.io/usage/models}{spaCy
 #'   language models} page.
 #' @param version character; spaCy version to install. Specify \code{"latest"}
@@ -49,7 +50,7 @@
 #' @examples 
 #' \dontrun{
 #' # install spaCy in a miniconda environment (macOS and Linux)
-#' spacy_install(lang_models = c("en", "de"), prompt = FALSE)
+#' spacy_install(lang_models = c("en_core_web_sm", "de_core_news_sm"), prompt = FALSE)
 #' 
 #' # install spaCy to an existing conda environment
 #' spacy_install(conda = "~/anaconda/bin/")
@@ -58,7 +59,7 @@
 #' @export
 spacy_install <- function(conda = "auto",
                           version = "latest",
-                          lang_models = "en",
+                          lang_models = "en_core_web_sm",
                           python_version = "3.6",
                           envname = "spacy_condaenv",
                           pip = FALSE,
@@ -69,6 +70,15 @@ spacy_install <- function(conda = "auto",
         stop("This function is available only for Windows, Mac, and Linux")
     }
 
+    # model name check
+    if (any(lang_models %in% c('en', 'de', 'es', 'pt', 'fr', 'it', 'nl', 'el', 'nb', 'lt') == TRUE)) {
+        model <-
+            lang_models[lang_models %in%
+                            c('en', 'de', 'es', 'pt', 'fr', 'it', 'nl', 'el', 'nb', 'lt') == TRUE][1]
+        stop('An abbreviation of the model name, "', model, '", is provided.\n',
+             '  Please use a full model name (e.g. "', model, '_core_', ifelse(model == 'en', 'web', 'news'),'_sm").\n')
+    }
+
     # verify 64-bit
     # if (.Machine$sizeof.pointer != 8) {
     #     stop("Unable to install TensorFlow on this platform.",
@@ -146,11 +156,11 @@ spacy_install <- function(conda = "auto",
 #' @examples
 #' \dontrun{
 #' # install spaCy in a virtualenv environment
-#' spacy_install_virtualenv(lang_models = c("en"))
+#' spacy_install_virtualenv(lang_models = c("en_core_web_sm"))
 #' }
 #' @export
 spacy_install_virtualenv <- function(version = "latest",
-                                     lang_models = "en",
+                                     lang_models = "en_core_web_sm",
                                      python_version = "3.6",
                                      python_path = NULL,
                                      prompt = TRUE) {
@@ -443,15 +453,14 @@ python_version <- function(python) {
 spacy_pkgs <- function(version, packages = NULL) {
     if (is.null(packages))
         packages <- sprintf("spacy%s",
-                            ifelse(version == "latest", "", paste0("==", version)))
+                            ifelse(version == "latest", "", paste0("=", version)))
     return(packages)
 }
 
 #' Uninstall spaCy conda environment
 #'
 #' Removes the conda environment created by spacy_install()
-#' @inheritParams reticulate::conda_list
-#' @param conda Path to conda executable, default to "auto" which automatically
+#' @param conda path to conda executable, default to "auto" which automatically
 #'   finds the path
 #' @param prompt logical; ask whether to proceed during the installation
 #' @param envname character; name of conda environment to remove
@@ -483,29 +492,38 @@ spacy_uninstall <- function(conda = "auto",
 
 #' Upgrade spaCy in conda environment
 #'
-#' @inheritParams reticulate::conda_list
 #' @param conda Path to conda executable. Default "auto" which automatically
 #'   find the path
 #' @param pip \code{TRUE} to use pip for installing spacy. If \code{FALSE}, conda 
 #' package manager with conda-forge channel will be used for installing spacy.
 
 #' @param lang_models Language models to be upgraded. Default NULL (No upgrade). 
-#'   A vector of multiple model names can be used (e.g. \code{c("en", "de")})
+#'   A vector of multiple model names can be used (e.g. \code{c("en_core_web_sm", "de_core_web_sm")})
 #' @param prompt logical; ask whether to proceed during the installation
 #' @param envname character; name of conda environment to upgrade spaCy
+#' @param update_conda logical; If \code{true}, the conda binary for the system will be updated to the latest version. 
+#'  Default \code{FALSE}.
 #' @export
 spacy_upgrade  <- function(conda = "auto",
                            envname = "spacy_condaenv",
                            prompt = TRUE,
                            pip = FALSE,
-                           lang_models = "en") {
+                           update_conda = FALSE,
+                           lang_models = "en_core_web_sm") {
 
-    message("checking spaCy version")
     conda <- reticulate::conda_binary(conda)
     if (!(envname %in% reticulate::conda_list(conda = conda)$name)) {
         message("Conda evnronment", envname, "does not exist")
     }
-
+    
+    if (update_conda == TRUE) {
+        message("Update conda binary")
+        args <- conda_args("update", "root", "conda")
+        result <- system2(conda, shQuote(args))
+        message("Conda is updated\n")
+    }
+    
+    message("checking spaCy version")
     condaenv_bin <- function(bin) path.expand(file.path(dirname(conda), bin))
     cmd <- sprintf("%s%s %s && pip search spacy%s",
                    ifelse(is_windows(), "", ifelse(is_osx(), "source ", "/bin/bash -c \"source ")),
@@ -530,12 +548,13 @@ spacy_upgrade  <- function(conda = "auto",
             cat("spaCy will be upgraded to version", latest_spacy, "\n")
             process_spacy_installation_conda(conda = conda,
                                              envname = envname,
-                                             version = "latest",
+                                             version = latest_spacy,
                                              lang_models = lang_models,
                                              python_version = "3.6",
                                              prompt = FALSE)
             message("\nSuccessfully upgraded\n",
-                    sprintf("Condaenv: %s; Langage model(s): ", envname), lang_models, "\n")
+                    sprintf("Condaenv: %s; Langage model(s): ", envname), lang_models, "\n",
+                    "For the upgrade to take effect, please restart R session")
         } else {
             if (pip == TRUE) {
                 cmd <- sprintf("%s%s %s && pip install --upgrade %s %s%s",
@@ -578,13 +597,14 @@ spacy_upgrade  <- function(conda = "auto",
             }
             process_spacy_installation_conda(conda = conda,
                                              envname = envname,
-                                             version = "latest",
+                                             version = latest_spacy,
                                              lang_models = lang_models,
                                              python_version = "3.6",
                                              prompt = FALSE,
                                              pip = pip)
             message("\nSuccessfully upgraded\n",
-                    sprintf("Condaenv: %s; Langage model(s): ", envname), lang_models, "\n")
+                    sprintf("Condaenv: %s; Langage model(s): ", envname), lang_models, "\n",
+                    "For the upgrade to take effect, please restart R session")
 
         } else {
             message("No upgrade is chosen")
@@ -649,4 +669,5 @@ conda_get_version <- function(major_version = NA, conda, envname) {
     }
     #version_check_regex <- sprintf(".+(%s.\\d+\\.\\d+).+", major_version)
     return(result[length(result)])
-}
\ No newline at end of file
+}
+
