@@ -62,6 +62,7 @@ spacy_tokenize.character <- function(x,
                                      multithread = TRUE,
                                      output = c("list", "data.frame"),
                                      ...) {
+    x <- structure(as.character(x), names = names(x))
     output <- match.arg(output)
     what <- match.arg(what)
 
@@ -76,7 +77,7 @@ spacy_tokenize.character <- function(x,
 
 
     if (all(!duplicated(docnames)) == FALSE) {
-        stop("Docmanes are duplicated.")
+        stop("Docnames are duplicated.")
     } else if (all(nchar(docnames) > 0L) == FALSE) {
         stop("Some docnames are missing.")
     }
